@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.91a
+// IPplan v4.92a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -85,6 +85,7 @@ if ($_GET || $_POST) {
     if ($action == "changeuserpw")          {  $formerror .= parseChangeUserPassword($editor, $ds);  }
     if ($action == "addusertogroup")        {  $formerror .= parseAddUserToGroupForm($editor,$ds);   }
     if ($action == "modifygroup")           {  $formerror .= parseModifyGroupForm($editor, $ds);     }
+    if ($action == "modifyuser")          {  $formerror .= parseModifyUserForm($editor, $ds);  }
     if ($action == "addgroupboundary")	{  $formerror .= parseAddGroupBoundaryForm($editor, $ds);}
 }
 
@@ -217,6 +218,7 @@ if ($formerror != "") {
     if ($action == "deletegroup")           {  insetrEditGroupForm($editor, $ds);     }
     if ($action == "deleteuserfromgroup")   {  /* done in function with ref var */    }
     if ($action == "changeuserpw")          {  insertEditUserForm($editor, $ds);      }
+    if ($action == "modifyuser")            {  insertEditUserForm($editor, $ds);      }
     if ($action == "addusertogroup")        {           			            }
     if ($action == "modifygroup")           {  insertEditGroupForm($editor, $ds);     }
     if ($action == "addgroupboundary")      {  insertEditGroupForm($editor, $ds);     }
@@ -301,15 +303,37 @@ function insertEditUserForm($w,$ds) {
     // First off we insert the user information and delete button.
     insert($w, $t=table(array("cols"=>"2","border"=>"0","cellspacing"=>"2","width"=>"100%")));
     insert($t, $c=cell());
-    insert($c ,block("<b>".my_("Editing User: $userid")."</b><br>"));
-    insert($c, block("<i>".my_("Real Name: ").$row["userdescrip"]."</i><br>"));
-    insert($c, block(my_("e-mail: ").$row["useremail"]));
+    insert($c ,block("<b>"));
+    insert($c ,text(my_("Editing User: ").$userid));
+    insert($c ,block("</b><br>"));
+    insert($c, block("<i>"));
+    insert($c, text(my_("Real Name: ").$row["userdescrip"]));
+    insert($c, block("</i><br>"));
+    insert($c, text(my_("e-mail: ").$row["useremail"]));
     insert($t, $c=cell(array("align"=>"right")));
     insert($c, $f = form(array("method"=>"post","action"=>$_SERVER["PHP_SELF"])));
     insert($f,hidden(array("name"=>"action","value"=>"deleteuser")));
     insert($f,hidden(array("name"=>"userid"   ,"value"=>"$userid")));
     insert($f,submit(array("value"=>my_("Delete User"))));
 
+    // Modify User Form
+
+    insert($w, $f1 = form(array("method"=>"post","action"=>$_SERVER["PHP_SELF"])));
+    insert($f1, $con=container("fieldset",array("class"=>"fieldset")));
+    insert($con, $legend=container("legend",array("class"=>"legend")));
+    insert($legend, text(my_("Modify user")));
+    insert($con,hidden(array("name"=>"userid"   ,"value"=>"$userid")));
+    insert($con,hidden(array("name"=>"action","value"=>"modifyuser")));
+    insert($con,textbr(my_("Real Name: ")));
+    insert($con,input_text(array("name"=>"userdescrip","value"=>$row["userdescrip"],"size"=>"80","maxlength"=>"80")));
+    insert($con,generic("br"));
+    insert($con,textbr(my_("E-mail address:")));
+    insert($con,input_text(array("name"=>"useremail","value"=>$row["useremail"],"size"=>"80","maxlength"=>"64")));
+    insert($con,generic("br"));
+    insert($con,generic("br"));
+    insert($con,submit(array("value"=>my_("Update"))));
+    insert($con,generic("br"));
+
     // Next we add the change password form.
 
     insert($w, $con=container("fieldset",array("class"=>"fieldset")));
@@ -407,8 +431,11 @@ function insertEditGroupForm($w,$ds) {
     $resaddr   =$row["resaddr"];
     insert($w, $t=table(array("width"=>"100%","cols"=>"2","border"=>"0","cellspacing"=>"0","valign"=>"middle")));
     insert($t, $c = cell());
-    insert($c, block("<b>".my_("Editing Group:")." $grp</b><br>"));
-    insert($c, block("<i>".my_(" Description: ")."</i>".$grpdescrip));
+    insert($c, block("<b>"));
+    insert($c, text(my_("Editing Group:")." $grp"));
+    insert($c, block("</b><br>"));
+    insert($c, block("<i>".my_(" Description: ")."</i>"));
+    insert($c, text($grpdescrip));
     insert($w,generic("br"));  
     insert($t,$c = cell (array("align"=>"right")));
     insert($c, $f = form(array("method"=>"post","action"=>$_SERVER["PHP_SELF"])));
@@ -689,10 +716,10 @@ function parseCreateUserForm($w,$ds) {
         $password1=$password2=rand(10000, 1000000);
     }
 
-    if (strlen($userid) < 2) {
+    if (strlen($userid) < 2 or strlen($userid) > 40) {
         $formerror .= my_("The user-id must be longer")."\n";
     }
-    if (strlen($userdescrip) < 2) {
+    if (strlen($userdescrip) < 2 or strlen($userdescrip) > 80) {
         $formerror .= my_("The user description must be longer")."\n";
     }
     if (strlen($password1) < 5 or strlen($password2) < 5) {
@@ -749,13 +776,13 @@ function parseCreateGroupForm($w,$ds) {
     $grpdescrip=trim($grpdescrip);
     $formerror="";
 
-    if (strlen($grp) < 2) {
+    if (strlen($grp) < 2 or strlen($grp) > 40) {
         $formerror .= my_("The group name must be longer")."\n";
     }
     if ($resaddr < 0 or $resaddr > 9999) {
         $formerror .= my_("Reserved addresses out of range")."\n";
     }
-    if (strlen($grpdescrip) < 2) {
+    if (strlen($grpdescrip) < 2 or strlen($grpdescrip) > 80) {
         $formerror .= my_("The group description must be longer")."\n";
     }
     if (ereg("[^[:alnum:]-]", $grp)) {
@@ -858,7 +885,7 @@ function parseDeleteForms($w, $ds) {
 
         if ($result) {
             $ds->DbfTransactionEnd();
-            insert($w,text(my_("User $userid deleted from group")));
+            insert($w,text(sprintf(my_("User %s deleted from group"), $userid)));
             if ($ref == "user")
                 insertEditUserForm($w, $ds);
             if ($ref == "grp")
@@ -906,7 +933,7 @@ function parseDeleteForms($w, $ds) {
 
         if ($result) {
             $ds->DbfTransactionEnd();
-            insert($w,text(my_("Group $grp deleted")));
+            insert($w,text(sprintf(my_("Group %s deleted"), $grp)));
         }
         else {
             $formerror .= my_("Group could not be deleted");
@@ -915,6 +942,36 @@ function parseDeleteForms($w, $ds) {
 } // end function
 
 
+function parseModifyUserForm($w, $ds) {
+
+    list($userid, $userdescrip, $useremail) = myRegister("S:userid S:userdescrip S:useremail");
+
+    $formerror="";
+
+    if ((strlen($useremail) > 0) && (!preg_match('/^[\w-\.]{1,}\@([\da-zA-Z-]{1,}\.){1,}[\da-zA-Z-]{2,3}$/', $useremail))) {
+        $formerror .= my_("Not a valid email address!")."\n";
+    }
+
+    if ($formerror == "" ) {
+        $ds->DbfTransactionStart();
+        $result=&$ds->ds->Execute("UPDATE users
+                SET userdescrip=".$ds->ds->qstr($userdescrip).",
+                useremail=".$ds->ds->qstr($useremail)."
+                WHERE userid=".$ds->ds->qstr($userid));
+        $ds->AuditLog(sprintf(my_("User %s modified"), $userid));
+
+        if ($result) {
+            $ds->DbfTransactionEnd();
+            insert($w,text(my_("User modified")));
+            insertEditUserForm($w,$ds);
+        }
+        else {
+            $formerror .= my_("User could not be modified")."\n";
+        }
+    }
+    return($formerror);
+}
+
 function parseChangeUserPassword($w, $ds) {
 
     list($password1, $password2, $userid) = myRegister("S:password1 S:password2 S:userid");
@@ -1015,7 +1072,7 @@ function parseModifyGroupForm($w, $ds) {
 
         if ($result) {
             $ds->DbfTransactionEnd();
-            insert($w,text(my_("Group $grp details modified")));
+            insert($w,text(sprintf(my_("Group %s details modified"), $grp)));
             insertEditGroupForm($w, $ds);
         }
         else {
