@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.91a
+// IPplan v4.92a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -49,12 +49,19 @@ foreach ($types_to_register as $type) {
 }
 
 // set the error reporting level for IPplan
-error_reporting(E_ALL ^ E_NOTICE);
+if (phpversion()<"5.3") {
+    error_reporting(E_ALL ^ E_NOTICE);
+}
+else {
+    error_reporting(E_ALL ^ E_NOTICE ^ E_DEPRECATED);
+}
 //error_reporting(E_ALL);
 // set to the user defined error handler
 set_error_handler("myErrorHandler");
 // turn off those pesky quotes
-set_magic_quotes_runtime(0);
+if (phpversion()<"5.3") {
+    set_magic_quotes_runtime(0);
+}
 
 /*********** end of global code which runs for each script *********/
 
@@ -623,7 +630,7 @@ function myheading($q, $title, $displaymenu=true) {
 
     insert($w,$con=container("div",array("class"=>"normalbox")));
     insert($w,$con1=container("div",array("class"=>"footerbox")));
-    insert($con1,block("IPPlan v4.91a"));
+    insert($con1,block("IPPlan v4.92a"));
     return $con;
 
 }
@@ -632,9 +639,9 @@ function myheading($q, $title, $displaymenu=true) {
 // or unserializes and pastes a cookie into a form
 // phpserializer.js and cookies.js must be pre-loaded on the webpage
 function myCopyPaste(&$f, $cookie, $formname) {
-    insert($f,block(" <a href='#' onclick='var php = new PHP_Serializer(); setCookie(\"".$cookie."\", php.serialize(getElements(\"".$formname."\"))); return false'>Copy</a>"));
+    insert($f,block(" <a href='#' onclick='var php = new PHP_Serializer(); setCookie(\"".$cookie."\", php.serialize(getElements(\"".$formname."\"))); return false'>".my_('Copy')."</a>"));
 
-    insert($f,block(" <a href='#' onclick='var php = new PHP_Serializer(); setElements(php.unserialize(getCookie(\"".$cookie."\")), \"".$formname."\"); return false'>Paste</a>"));
+    insert($f,block(" <a href='#' onclick='var php = new PHP_Serializer(); setElements(php.unserialize(getCookie(\"".$cookie."\")), \"".$formname."\"); return false'>".my_('Paste')."</a>"));
 }
 
 // draw a search box with associated search type if required
@@ -701,7 +708,7 @@ class mySearch {
         }
 
         insert($con,submit(array("value"=>my_("Submit"))));
-        insert($con,block(" <a href='#' onclick='SEARCH.".$this->frmvar.".value=\"\"; SEARCH.submit();'>Reset Search</a>"));
+        insert($con,block(" <a href='#' onclick='SEARCH.".$this->frmvar.".value=\"\"; SEARCH.submit();'>".my_("Reset Search")."</a>"));
 
 
     }
