@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.91a
+// IPplan v4.92a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -611,6 +611,12 @@ $export->addRow(array("ip_addr", "user", "location", "description", "hostname",
 $export->saveRow();
 
 $pollcnt=array("d"=>0, "w"=>0, "m"=>0, "y"=>0);
+// note for translations to work here, the next field should have exactly 4x elements
+$pollflag=split(":", my_("D:W:M:Y"));
+$pollflag["d"]=$pollflag[0];
+$pollflag["w"]=$pollflag[1];
+$pollflag["m"]=$pollflag[2];
+$pollflag["y"]=$pollflag[3];
 $cnt=0;
 $lst=array();
 while($row = $rr->FetchRow()) {
@@ -752,19 +758,19 @@ while($row = $rr->FetchRow()) {
     // display info about when last device was polled
     insert($t,$c = cell());
     if ($polled or $result->UnixDate($row["lastpol"]) > time()-(3600*24)) {
-        insert($c,text("D"));
+        insert($c,text($pollflag["d"]));
         $pollcnt["d"]++;
     }
     else if ($result->UnixDate($row["lastpol"]) > time()-(3600*24*7)) {
-        insert($c,text("W"));
+        insert($c,text($pollflag["w"]));
         $pollcnt["w"]++;
     }
     else if ($result->UnixDate($row["lastpol"]) > time()-(3600*24*30)) {
-        insert($c,text("M"));
+        insert($c,text($pollflag["m"]));
         $pollcnt["m"]++;
     }
     else if ($result->UnixDate($row["lastpol"]) > time()-(3600*24*365)) {
-        insert($c,text("Y"));
+        insert($c,text($pollflag["y"]));
         $pollcnt["y"]++;
     }
     $export->addCell($row["lastpol"]);
