@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.91a
+// IPplan v4.92a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -357,7 +357,8 @@ if (!$_POST || $formerror) {
     }
 
     $countrycodes=array(
-            ""=>"None",
+            ""=>my_("None"),
+	    // For the moment it seems overkill to translate the names of the nations.
             "AD"=>"AD   Andorra",
             "AE"=>"AE   United Arab Emirates",
             "AF"=>"AF   Afghanistan",
@@ -603,7 +604,8 @@ if (!$_POST || $formerror) {
             "ZW"=>"ZW   Zimbabwe");
 
     $statecodes=array(
-            ""=>"None",
+            ""=>my_("None"),
+	    // For the moment it seems overkill to translate the names of the states.
             "AL"=>"AL	Alabama",
             "AK"=>"AK	Alaska",
             "AZ"=>"AZ	Arizona",
