@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.91a
+// IPplan v4.92a
 // Aug 24, 2001
 //
 // Modified by Tony D. Koehn February 2003
@@ -440,7 +440,7 @@ if ($action=="edit") {
 myError($w,$p, $formerror, FALSE);
 
 insert($w,heading(3, "$title."));
-insert($w,textbr("Maintain forward zone domain records."));
+insert($w,textbr(my_("Maintain forward zone domain records.")));
 
 
 // start form
