@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.91a
+// IPplan v4.92a
 // Aug 24, 2001
 //
 // This program is free software; you can redistribute it and/or modify
@@ -546,7 +546,7 @@ insert($con,input_text(array("name"=>"user",
                            "size"=>"80",
                            "maxlength"=>"80")));
 insert($con,block(" <a href='#' onclick='MODIFY.user.value=\"".
-                    DHCPRESERVED."\";'>DHCP address</a>"));
+                    DHCPRESERVED."\";'>".my_("DHCP address")."</a>"));
 insert($con,textbrbr(my_("Location")));
 insert($con,input_text(array("name"=>"location",
                            "value"=>$location,
