@@ -1,6 +1,6 @@
 <?php
 
-// IPplan v4.91a
+// IPplan v4.92a
 // Aug 24, 2001
 //
 // Modified by Tony D. Koehn February 2003
@@ -329,7 +329,7 @@ if ($action=="export") {
 myError($w,$p, $formerror, FALSE);
 
 insert($w,heading(3, "$title."));
-insert($w,text("Create and maintain reverse DNS zones. Reverse zone records are extracted from the host field of subnets created for this customer."));
+insert($w,text(my_("Create and maintain reverse DNS zones. Reverse zone records are extracted from the host field of subnets created for this customer.")));
 insert($w,block(my_(" Zones in bold and tagged with a &Dagger; have changed domain records, but have not been exported yet.")));
 insert($w,textbrbr(my_("NOTE: Changed domain records are IP records that have been modified since the domain serial date. Thus even after an export the zone may still show changed as the resolution of the serial date is one day. The last modified date is the date when the SOA details for this zone have last changed.")));
 insert($w,textbr());
