@@ -49,7 +49,7 @@ insert($w, script("",array("language"=>"JavaScript","type"=>"text/javascript","s
 // display opening text
 insert($w,heading(3, my_("Display subnets.")));
 
-insert($w,text("Click on customer/AS to display all associated subnets, click on the area to display all subnets in area and contained ranges, click on a range to display only subnets associated with that range. Subnets not within an area or range can be viewed by selecting the customer/AS.")); 
+insert($w,text(my_("Click on customer/AS to display all associated subnets, click on the area to display all subnets in area and contained ranges, click on a range to display only subnets associated with that range. Subnets not within an area or range can be viewed by selecting the customer/AS."))); 
 
 insert($w,block("<p><hr>"));
 
